/*jshint esversion: 6 */

jQuery.noConflict();
(function($, PLUGIN_ID) {
    'use strict';
    var terms = {
        'en': {
        },
        'ja': {
            hubId: 'Hub IDを入力するフィールド',
            hubIdDescription: 'Hub IDを入力してください',
            hubspotCode: 'Hubspot codeに指定するフィールド',
            description1: 'Hubspot codeを格納するフィールドを選択していください',
            spaceSelect: 'iframeを表示するスペース',
            description2: 'iframeを表示するスペースフィールドのコードを設定してください',
            iframeSetting: 'iframeを表示する大きさ',
            description3: 'iframeを表示する大きさを指定してください。未指定の場合は1000×1000になります。',
            errorMessage: 'エラーです',
            saveButton: '保存する',
            cancelButton: 'キャンセル',
        },
        'zh': {
        }
    };
    var lang = kintone.getLoginUser().language;
    var i18n = (lang in terms) ? terms[lang] : terms.en;
    var CONF = kintone.plugin.app.getConfig(PLUGIN_ID);
    const OBJECT_INDEX = 2; //object - 1

    function setDefault() {
        if (Object.keys(CONF).length > 0) {
            $('#hubId').val(CONF.hubId);
            $('#ispace').val(CONF.ispace);
            $('#iframe-width').val(CONF.iframeWidth);
            $('#iframe-height').val(CONF.iframeHeight);
            for (var i = 1; i < OBJECT_INDEX; i++) {
                $('#select' + i).val(CONF['select' + i]);
            }
        }
    }

    function escapeHtml(htmlstr) {
        return htmlstr.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;')
            .replace(/'/g, '&quot;').replace(/'/g, '&#39;');
    }
  
    function setDropdown() {
        // get the form fields info and put them in the selection boxes
        var url = kintone.api.url('/k/v1/preview/app/form/fields', true);
        kintone.api(url, 'GET', {'app': kintone.app.getId()}, function(resp) {

            var configHTML = $('#iframe-plugin').html();
            var template = $.templates(configHTML);
            $('div#iframe-plugin').html(template.render({'terms': i18n}));

            appendEvents();

            var $option = $('<option>');

            for (var key in resp.properties) {
                if (!Object.prototype.hasOwnProperty.call(resp.properties, key)) {
                    continue;
                }
                var prop = resp.properties[key];
                switch (prop.type) {
                    case 'SINGLE_LINE_TEXT':
                    case 'MULTI_LINE_TEXT':
                        for (var m = 1; m < OBJECT_INDEX; m++) {
                            $option.attr('value', escapeHtml(prop.code));
                            $option.text(escapeHtml(prop.label));
                            $('#select' + m).append($option.clone());
                        }
                        break;
                    case 'SPACER':
                        for (var l = 1; l < OBJECT_INDEX; l++) {
                            $option.attr('value', escapeHtml(prop.code));
                            $option.text(escapeHtml(prop.label));
                            $('#select-s' + m).append($option.clone());
                        }
                        break;
                    case 'RICH_TEXT':
                    case 'DATETIME':
                    case 'NUMBER':
                    case 'RADIO_BUTTON':
                    case 'CHECK_BOX':
                    case 'MULTI_SELECT':
                    case 'DROP_DOWN':
                    case 'DATE':
                    case 'TIME':
                    case 'LINK':
                    case 'USER_SELECT':
                    case 'ORGANIZATION_SELECT':
                    case 'GROUP_SELECT':
                 default:
                        break;
                }
            }
            setDefault();
        });
    }
  
    var appendEvents = function() {
        $('#submit').click(function() {
            const config = [];
            config.hubId = $('#hubId').val();
            config.ispace = $('#ispace').val();
            config.iframeWidth = ($('#iframe-width').val())?$('#iframe-width').val():'1000';
            config.iframeHeight = ($('#iframe-height').val())?$('#iframe-height').val():'1000';
            for (var i = 1; i < OBJECT_INDEX; i++) {
                config['select' + i] = $('#select' + i).val();
            }
            kintone.plugin.app.setConfig(config);
        });
        $('#cancel').click(function() {
            window.history.back();
        });
    };

    setDropdown();
})(jQuery, kintone.$PLUGIN_ID);
